Docker Registry Client
======================

|Build Status|

*Description*

A Python REST client for the Docker Registry

It's useful for automating image tagging and untagging

.. |Build Status| image:: https://travis-ci.org/yodle/docker-registry-client.svg?branch=master
   :target: https://travis-ci.org/yodle/docker-registry-client

Alternatives
------------

* `python-dxf <https://pypi.python.org/pypi/python-dxf>`_ (only supports V2)
